##  Setting Your Notification Preferences
To adjust your notification preferences, in the user profile menu, select My Settings, then select Notifications in the left-side panel. On the Notifications page, you can set the notification frequency for specific items. Note the following:
  * The default notification frequency for each item is set by the workspace admin. Additionally, the admin can enable or disable available frequency options that users can choose from, such as Never, Instant, Daily, or Weekly. If specific options don’t appear on the list, it means that the admin has turned them off.
  * For items with the frequency set to Daily or Weekly, a consolidated notification message including multiple items is sent.
  * You can turn off notifications for a specific item by setting the frequency to Never (if available).
  * If the workspace admin has disabled all notifications for a specific channel, a corresponding message appears on that tab.


**Tip**
We recommend keeping your workspace notifications active. This allows you to ensure that you stay updated on important changes, keep track of your tasks, and maintain effective collaboration with your team.
